{
    "$graph": [
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "javatools"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "coresMin": 2,
                    "coresMax": 2
                }
            ],
            "hints": [
                {
                    "keep_cache": 4096,
                    "class": "http://arvados.org/cwl#RuntimeConstraints"
                }
            ],
            "baseCommand": "bash",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#filter.cwl/bashscript"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 5
                    },
                    "id": "#filter.cwl/cutoff"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#filter.cwl/filter_gvcf"
                },
                {
                    "type": "Directory",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#filter.cwl/gffDir"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#filter.cwl/gffPrefix"
                }
            ],
            "id": "#filter.cwl",
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "filtered/*"
                    },
                    "id": "#filter.cwl/out1"
                }
            ]
        },
        {
            "class": "ExpressionTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "loadListing": "shallow_listing",
                    "class": "http://commonwl.org/cwltool#LoadListingRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "loadContents": true
                        }
                    },
                    "id": "#getCollections.cwl/datafilenames"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "loadContents": true
                        }
                    },
                    "id": "#getCollections.cwl/datafilepdh"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "Directory"
                    },
                    "id": "#getCollections.cwl/collectiondir"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#getCollections.cwl/fileprefix"
                }
            ],
            "expression": "${\n  var fileprefix=[];\n  var collectiondir=[];\n  var ssdir=[];\n\n\n  for (var jj = 0; jj < inputs.datafilenames.length; jj++) {\n   var names=inputs.datafilenames[jj].contents.split('\\n');\n   var nblines1=names.length;\n   for (var j = 0; j < nblines1-1; j++) {\n    var nn=names[j];\n    fileprefix.push(nn);  \n    }\n   }\n\n  for (var ii = 0; ii < inputs.datafilepdh.length; ii++) {\n    var pdhs=inputs.datafilepdh[ii].contents.split('\\n');\n    var nblines2=pdhs.length;\n    for (var i = 0; i < nblines2-1; i++) {\n      var ss=pdhs[i];\n      var ssdir={\"class\": \"Directory\", \"location\": \"keep:\" + ss};\n      collectiondir.push(ssdir);\n      }\n    }\n\n  return {\"fileprefix\": fileprefix,\"collectiondir\":collectiondir};\n  }\n",
            "id": "#getCollections.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "javatools"
                },
                {
                    "class": "ResourceRequirement",
                    "coresMin": 2,
                    "coresMax": 2
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "hints": [
                {
                    "keep_cache": 4096,
                    "class": "http://arvados.org/cwl#RuntimeConstraints"
                },
                {
                    "loadListing": "shallow_listing",
                    "class": "http://commonwl.org/cwltool#LoadListingRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/bashscript"
                },
                {
                    "type": "string",
                    "id": "#main/cutoff"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/datafilenames"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/datafilepdh"
                },
                {
                    "type": "File",
                    "id": "#main/filter_gvcf"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "Directory"
                    },
                    "outputSource": "#main/step2/out1",
                    "id": "#main/out1"
                }
            ],
            "steps": [
                {
                    "run": "#getCollections.cwl",
                    "in": [
                        {
                            "source": "#main/datafilenames",
                            "id": "#main/step1/datafilenames"
                        },
                        {
                            "source": "#main/datafilepdh",
                            "id": "#main/step1/datafilepdh"
                        }
                    ],
                    "out": [
                        "#main/step1/fileprefix",
                        "#main/step1/collectiondir"
                    ],
                    "id": "#main/step1"
                },
                {
                    "scatter": [
                        "#main/step2/gffPrefix",
                        "#main/step2/gffDir"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#main/bashscript",
                            "id": "#main/step2/bashscript"
                        },
                        {
                            "source": "#main/cutoff",
                            "id": "#main/step2/cutoff"
                        },
                        {
                            "source": "#main/filter_gvcf",
                            "id": "#main/step2/filter_gvcf"
                        },
                        {
                            "source": "#main/step1/collectiondir",
                            "id": "#main/step2/gffDir"
                        },
                        {
                            "source": "#main/step1/fileprefix",
                            "id": "#main/step2/gffPrefix"
                        }
                    ],
                    "run": "#filter.cwl",
                    "out": [
                        "#main/step2/out1"
                    ],
                    "id": "#main/step2"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0",
    "$namespaces": {
        "arv": "http://arvados.org/cwl#",
        "cwltool": "http://commonwl.org/cwltool#"
    }
}
